==> integration-cli-2.4.1.tar.gz: integration-cli-2.4.1/cli.py <==
import click
import os
from time import sleep
from smart_cli.helpers import FileManager, find_django_manager, install_dependies
from smart_cli.colors import Base


@click.group()
def cli():
    pass


@cli.command()
@click.option('--name', default='project',
    help='This name of your project')
@click.argument('name', type=click.STRING, default='project', required=True)
@click.argument('type', type=click.STRING, default='widget', required=True)
@click.option('--type', default='widget',
    help='Choose type of your project(oauth, widget)')
def init(name, type):
    if type.lower() not in ['widget', 'oauth', 'crm']:
        raise Exception("Invalid type, type muste oauth or widget")
    file_manager = FileManager(name)
    print(Base.HEADER, f"-=-=-: STARTING PROJECT: {name} :-=-=-",Base.END)
    os.system(f'django-admin startproject {name}')
    print(Base.OKBLUE, f"-=-=-: init basic application for {name} :-=-=-",Base.END)
    sleep(2)
    if type.lower() == 'widget':
        os.popen(f'cp -R {file_manager.integration_dir}/integration_files/widget/* {name}')
    elif type.lower() == 'oauth':
        os.popen(f'cp -R {file_manager.integration_dir}/integration_files/oauth/* {name}')
    elif type.lower() == 'crm':
        while True:
            print("================")
            auth_type = input("Chose auth type(basic, oauth): ")
            print("================")
            if auth_type.lower() == 'basic':
                os.popen(f'cp -R {file_manager.integration_dir}/integration_files/widget/* {name}')
                os.popen(f'cp -R {file_manager.integration_dir}/integration_files/crm/basic* {name}')
                break
            if auth_type.lower() == 'oauth':
                os.popen(f'cp -R {file_manager.integration_dir}/integration_files/oauth/* {name}')
                os.popen(f'cp -R {file_manager.integration_dir}/integration_files/crm/oauth* {name}')
                break
            else:
                print(Base.WARNING, "WARNING chose valid auth_type(basic, oauth):", Base.END)
    else:
        raise Exception("Invalid type")
    os.popen(f'cp -R {file_manager.integration_dir}/integration_files/methods/ {name}')
    
    print(Base.OKBLUE, f"-=-=-: INSTALL DEPENDIES FOR PROJECT: {name} :-=-=-", Base.END)
    install_dependies()
    
    print(Base.OKGREEN, "-=-=-: FINISH INSTALL DEPENDIES :-=-=-", Base.END)
    sleep(4)
    print(Base.HEADER,f"-=-=-: STARTING CREATE django project :-=-=-", Base.END)
    file_manager.rewrite_settings()
    sleep(6)
    print(Base.OKBLUE, f"-=-=-: Created :-=-=-", Base.END)
    sleep(2)
    print(Base.OKGREEN,"-=-=-: DONE :-=-=-", Base.END)


@cli.command()
@click.option('--command', default='runserver',
    help='This name of django command')
@click.argument('command', type=click.STRING, default='runserver', required=True)
def django(command):
    manage = find_django_manager()
    os.system(f"python ./{manage} {command}")


@cli.command()
@click.option('--command', default='runserver',
    help='This name of django command')
@click.argument('command', type=click.STRING, default='tail', required=True)
def zappa(command, *params):
    str_params = " ".join(p for p in params)
    os.system(f"zappa {command} {str_params}")

==> integration-cli-2.4.2.tar.gz: integration-cli-2.4.2/cli.py <==
import click
import os
from time import sleep
from smart_cli.helpers import FileManager, find_django_manager, install_dependies
from smart_cli.colors import Base


@click.group()
def cli():
    pass


@cli.command()
@click.option('--name', default='project',
    help='This name of your project')
@click.argument('name', type=click.STRING, default='project', required=True)
@click.argument('type', type=click.STRING, default='widget', required=True)
@click.option('--type', default='widget',
    help='Choose type of your project(oauth, widget)')
@click.argument('structure', type=click.STRING, default='widget', required=True)
@click.option('--structure', default='default',
    help='Choose structure type(default, inside)')
def init(name, type, structure):
    if type.lower() not in ['widget', 'oauth', 'crm']:
        raise Exception("Invalid type, type muste oauth or widget")
    file_manager = FileManager(name)
    print(Base.HEADER, f"-=-=-: STARTING PROJECT: {name} :-=-=-",Base.END)
    if structure.lower() == 'inside':
        os.system(f'django-admin startproject {name} .')
    else:
        os.system(f'django-admin startproject {name}')
    print(Base.OKBLUE, f"-=-=-: init basic application for {name} :-=-=-",Base.END)
    sleep(2)
    if type.lower() == 'widget':
        os.popen(f'cp -R {file_manager.integration_dir}/integration_files/widget/* {name}')
    elif type.lower() == 'oauth':
        os.popen(f'cp -R {file_manager.integration_dir}/integration_files/oauth/* {name}')
    elif type.lower() == 'crm':
        while True:
            print("================")
            auth_type = input("Chose auth type(basic, oauth): ")
            print("================")
            if auth_type.lower() == 'basic':
                os.popen(f'cp -R {file_manager.integration_dir}/integration_files/widget/* {name}')
                os.popen(f'cp -R {file_manager.integration_dir}/integration_files/crm/basic* {name}')
                break
            if auth_type.lower() == 'oauth':
                os.popen(f'cp -R {file_manager.integration_dir}/integration_files/oauth/* {name}')
                os.popen(f'cp -R {file_manager.integration_dir}/integration_files/crm/oauth* {name}')
                break
            else:
                print(Base.WARNING, "WARNING chose valid auth_type(basic, oauth):", Base.END)
    else:
        raise Exception("Invalid type")
    os.popen(f'cp -R {file_manager.integration_dir}/integration_files/methods/ {name}')
    
    print(Base.OKBLUE, f"-=-=-: INSTALL DEPENDIES FOR PROJECT: {name} :-=-=-", Base.END)
    install_dependies()
    
    print(Base.OKGREEN, "-=-=-: FINISH INSTALL DEPENDIES :-=-=-", Base.END)
    sleep(4)
    print(Base.HEADER,f"-=-=-: STARTING CREATE django project :-=-=-", Base.END)
    file_manager.rewrite_settings()
    sleep(6)
    print(Base.OKBLUE, f"-=-=-: Created :-=-=-", Base.END)
    sleep(2)
    print(Base.OKGREEN,"-=-=-: DONE :-=-=-", Base.END)


@cli.command()
@click.option('--command', default='runserver',
    help='This name of django command')
@click.argument('command', type=click.STRING, default='runserver', required=True)
def django(command):
    manage = find_django_manager()
    os.system(f"python ./{manage} {command}")


@cli.command()
@click.option('--command', default='runserver',
    help='This name of django command')
@click.argument('command', type=click.STRING, default='tail', required=True)
def zappa(command, *params):
    str_params = " ".join(p for p in params)
    os.system(f"zappa {command} {str_params}")
